import requests

class Proovl:
    def __init__(self, user, token, from_num):
        self.user = user
        self.token = token
        self.from_num = from_num
        self.base_url = 'https://www.proovl.com/api/send.php'

    def send_sms(self, destination, message):
        params = {
            'user': self.user,
            'token': self.token,
            'from': self.from_num,
            'to': destination,
            'text': message
        }
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36',
            'Accept-Encoding': 'gzip, deflate, br',
            'Accept-Language': 'en-US,en;q=0.9',
            'Connection': 'keep-alive',
            'Upgrade-Insecure-Requests': '1'
        }
        response = requests.get(self.base_url, params=params, headers=headers)
        return response.text

    def send_bulk_sms(self, destinations, message):
        numbers = destinations.split(';')
        results = []
        for number in numbers:
            params = {
                'user': self.user,
                'token': self.token,
                'from': self.from_num,
                'to': number,
                'text': message
            }
            headers = {
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36',
                'Accept-Encoding': 'gzip, deflate, br',
                'Accept-Language': 'en-US,en;q=0.9',
                'Connection': 'keep-alive',
                'Upgrade-Insecure-Requests': '1'
            }
            response = requests.get(self.base_url, params=params, headers=headers)
            result = {'number': number, 'response': response.text}
            results.append(result)
        return results
		


from setuptools import setup, find_packages

setup(
    name='proovl-sms',
    version='0.1.4',
    author='Tomas',
    author_email='',
    description='A Python library for sending SMS messages using Proovl API',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://www.proovl.com',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Communications :: Telephony',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
